{% extends "waliki/detail.html" %} {% load i18n %} {% block title %}

### {% trans "History" %}: /{{ page.slug }}

{% endblock title %} {% block content %} {% csrf_token %}

{% for version in history %}
| {{ version.commit }} | {{ version.author }} | {{ version.date_relative }} | {{ version.message }} |
{% endfor %}

{% if history|length > 10 %}
{% trans "Back to top" %}
{% endif %} {% endblock content %} {% block extra_script %}
{% endblock %}